unit unConfigure;
{
    LiveInCode - a graphical front-end to LineInCode
    Copyright (C) 2003-2004 Roman Mamedov
    <E-Mail: roman@rm.pp.ru, Website: http://rm.pp.ru/?1.liveincode>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, unRM_IniWork, unRM_FileFuncs;

type
  TfmConfig = class(TForm)
    btOK: TButton;
    gbVorbis: TGroupBox;
    gbCustom: TGroupBox;
    rbOgg: TRadioButton;
    gbGeneral: TGroupBox;
    cbRate: TComboBox;
    Label1: TLabel;
    Label2: TLabel;
    cbBits: TComboBox;
    Label3: TLabel;
    cbChannels: TComboBox;
    Label4: TLabel;
    tbOggQuality: TTrackBar;
    edOggQuality: TEdit;
    edCommandLine: TEdit;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    btCancel: TButton;
    Label8: TLabel;
    edDestDir: TEdit;
    btBrowse: TButton;
    Label9: TLabel;
    edOggEncoder: TEdit;
    gbProfiles: TGroupBox;
    cbProfile: TComboBox;
    btSaveAsProfile: TButton;
    btDeleteProfile: TButton;
    open: TOpenDialog;
    rbCustom: TRadioButton;
    btRename: TButton;
    procedure tbOggQualityChange(Sender: TObject);
    procedure edOggQualityChange(Sender: TObject);
    procedure btOKClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btCancelClick(Sender: TObject);
    procedure btBrowseClick(Sender: TObject);
    procedure cbProfileChange(Sender: TObject);
    procedure btSaveAsProfileClick(Sender: TObject);
    procedure btDeleteProfileClick(Sender: TObject);
    procedure btRenameClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure SaveProfile(ProfileName:String);
    procedure LoadProfile(ProfileName:String);
    procedure UpdateProfileList(AndFocusOnProfile:String);        
  end;

var
  fmConfig: TfmConfig;

implementation

uses unLiveInCode, unCommonTypes;

{$R *.dfm}

procedure TfmConfig.UpdateProfileList(AndFocusOnProfile:String);
var FocusOn:String;
    filenames:TStringList;
    c:Integer;
begin
  if AndFocusOnProfile = '' then
    FocusOn := cbProfile.Text
  else
    FocusOn := AndFocusOnProfile;
  cbProfile.Clear;
  filenames := EnumFiles(PROFILEDIR + '\*.ini',False);
  if filenames.Count > 0 then begin
    for c:=0 to filenames.Count - 1 do begin
      filenames.Strings[c] := ChangeFileExt(filenames.Strings[c],'');
    end;
    cbProfile.Items.AddStrings(filenames);
  end else begin
    cbProfile.Items.Add('Default');
    MakeEmptyFile(PROFILEDIR + '\Default.ini');  
  end;
  try
    cbProfile.ItemIndex := cbProfile.Items.IndexOf(FocusOn);
  except
    cbProfile.ItemIndex := 0;
  end;
  if cbProfile.Text = '' then cbProfile.ItemIndex := 0;
end;

procedure TfmConfig.LoadProfile(ProfileName:String);
var pini:TRMIniFile;
begin
  pini := TRMIniFile.Create(PROFILEDIR + '\' + ProfileName + '.ini');
  cbRate.Text := pini.Read(INIGENERAL, 'rate', '44100');
  cbBits.Text := pini.Read(INIGENERAL, 'bits', '16');
  cbChannels.Text := pini.Read(INIGENERAL, 'channels', '2');
  edDestDir.Text := pini.Read(INIGENERAL, 'dir', '');
  edOggQuality.Text := pini.Read(INIOGG, 'quality', '6');
  edOggQualityChange(Self);
  edOggEncoder.Text := pini.Read(INIOGG, 'encoder', 'oggenc');
  edCommandLine.Text := pini.Read(INICUSTOM,'commandline',DEFAULTCUSTOMLINE);
  rbOgg.Checked := pini.Read(INIOGG,'enabled',True);
  rbCustom.Checked := pini.Read(INICUSTOM,'enabled',False) and(not rbOgg.Checked);
end;

procedure TfmConfig.SaveProfile(ProfileName:String);
var pini:TRMIniFile;
begin
  pini := TRMIniFile.Create(PROFILEDIR + '\' + ProfileName + '.ini');
  pini.Write(INIGENERAL, 'rate', cbRate.Text);
  pini.Write(INIGENERAL, 'bits', cbBits.Text);
  pini.Write(INIGENERAL, 'channels', cbChannels.Text);
  pini.Write(INIGENERAL, 'dir', edDestDir.Text);
  pini.Write(INIOGG, 'quality', edOggQuality.Text);
  pini.Write(INIOGG, 'encoder', edOggEncoder.Text);
  pini.Write(INICUSTOM,'commandline', edCommandLine.Text);
  pini.Write(INIOGG,'enabled', rbOgg.Checked);
  pini.Write(INICUSTOM,'enabled', rbCustom.Checked);
  pini.Free;
end;

procedure TfmConfig.tbOggQualityChange(Sender: TObject);
begin
  edOggQuality.Text := FloatToStr(tbOggQuality.Position/10);
end;

procedure TfmConfig.edOggQualityChange(Sender: TObject);
begin
  try
    tbOggQuality.Position := Trunc(StrToFloat(edOggQuality.Text)*10);
  except
  end;
end;

procedure TfmConfig.FormCreate(Sender: TObject);
begin
  UpdateProfileList(ini.Read(INIGENERAL, 'profile','Default'));
  LoadProfile(cbProfile.Text);
end;

procedure TfmConfig.btOKClick(Sender: TObject);
begin
  ini.Write(INIGENERAL, 'profile',cbProfile.Text);
  SaveProfile(cbProfile.Text);
  Self.Close;
end;

procedure TfmConfig.btCancelClick(Sender: TObject);
begin
  Self.Close;
end;

procedure TfmConfig.btBrowseClick(Sender: TObject);
begin
  open.FileName := 'Filename will be ignored';
  if open.Execute then begin
    edDestDir.Text := ExtractFilePath(open.Filename);     
  end;
end;

procedure TfmConfig.cbProfileChange(Sender: TObject);
begin
  LoadProfile(cbProfile.Text);
end;

procedure TfmConfig.btSaveAsProfileClick(Sender: TObject);
var profilename:String;
begin
  profilename := InputBox('Save a new profile','Please enter the name for a new profile:',cbProfile.Text);
  profilename := trim(profilename);
  if profilename='' then Exit;
  SaveProfile(profilename);
  UpdateProfileList(profilename);
end;

procedure TfmConfig.btDeleteProfileClick(Sender: TObject);
begin
  DeleteFile(PROFILEDIR + '\' + cbProfile.Text + '.ini');
  UpdateProfileList('');
  LoadProfile(cbProfile.Text);
end;

procedure TfmConfig.btRenameClick(Sender: TObject);
var profilename:String;
begin
  profilename := InputBox('Rename','Please enter a new name for "' + cbProfile.Text + '":',cbProfile.Text);
  profilename := trim(profilename);
  if profilename = '' then Exit;
  RenameFile(PROFILEDIR + '\' + cbProfile.Text + '.ini', PROFILEDIR + '\' + profilename + '.ini');
  UpdateProfileList(profilename);
  LoadProfile(profilename);
end;

end.
