unit unRM_AboutBox;
{
    unRM_AboutBox - a unit to show nice "About" boxes 
    Copyright (C) 2003 Roman Mamedov
    <E-Mail: roman@rm.pp.ru, Website: http://rm.pp.ru/?en>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}

interface

uses
  Windows, SysUtils, Classes, Controls, Forms, Dialogs,
  StdCtrls, shellapi, ExtCtrls, Graphics;

type TAboutBoxInfo = record
  ProgramName, Version, ReleaseDate, Copyright: string;
  Thanks, Description, License: string;
  EMail, WebPage: string;
  Icon: TIcon;
end;

type
  TfmAbout = class(TForm)
    lName: TLabel;
    btOK: TButton;
    lCr: TLabel;
    lHomepage: TLabel;
    lEmail: TLabel;
    img: TImage;
    edInfo: TMemo;
    btLicense: TButton;
    procedure WebLinkClick(Sender: TObject);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
    procedure btLicenseClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    FTextLicense, FTextInfo:String;
  end;

procedure RMShowModalAboutBox(ABI: TAboutBoxInfo);

// Center ChildForm in MainForm
procedure CenterChildForm(MainForm, ChildForm: TForm);
// Check whether the form is within screen bounds and move it if it's not
procedure MakeSureFormInScreen(Form:TForm);

implementation

{$R *.DFM}

procedure MakeSureFormInScreen(Form:TForm);
begin
  if Form.Top + Form.Height > Screen.Height then
    Form.Top := Screen.Height - Form.Height - 10;
  if Form.Left + Form.Width > Screen.Width then
    Form.Left := Screen.Width - Form.Width - 10;
end;

procedure CenterChildForm(MainForm, ChildForm: TForm);
begin
  ChildForm.Top := MainForm.Top + ((MainForm.Height - ChildForm.Height) div 2);
  ChildForm.Left := MainForm.Left + ((MainForm.Width - ChildForm.Width) div 2);
end;

procedure RMShowModalAboutBox(ABI: TAboutBoxInfo);
var fmAbout: TfmAbout;
    abv:String;
begin
  fmAbout := TfmAbout.Create(Application);
  fmAbout.img.Picture.Icon := ABI.Icon;
  if ABI.Version <>'' then abv := ' v' + ABI.Version else abv :='';
  fmAbout.lName.Caption := ABI.ProgramName + abv + ','#13#10'released on ' + ABI.ReleaseDate + '.';
  fmAbout.FTextInfo := ABI.Description;
  if ABI.License <> '' then begin
    fmAbout.btLicense.Visible := True;
    fmAbout.FTextLicense := ABI.License;    
  end;
  fmAbout.lCr.Caption := ABI.Copyright;
  if ABI.EMail = '' then
    fmAbout.lEmail.Visible := False
  else
    fmAbout.lEmail.Hint := ABI.EMail;
  if ABI.WebPage = '' then
    fmAbout.lHomepage.Visible := False
  else
    fmAbout.lHomepage.Hint := ABI.WebPage;
  fmAbout.edInfo.Text := ABI.Description;
  fmAbout.ShowModal;
  fmAbout.Free;
end;

procedure TfmAbout.WebLinkClick(Sender: TObject);
var
  Link: string;
begin
  if (Sender as TControl) = lHomepage then
    Link := lHomepage.Hint
  else if (Sender as TControl) = lEmail then
    Link := 'mailto:' + lEmail.Hint
  else
    Exit;
  ShellExecute(Self.Handle, 'open', PChar(Link), '', '', SW_SHOWNORMAL);
end;

procedure TfmAbout.FormKeyPress(Sender: TObject; var Key: Char);
begin
  if Ord(Key)=27 then btOK.Click;
end;

procedure TfmAbout.btLicenseClick(Sender: TObject);
begin
  if btLicense.Caption = 'License...' then begin
    btLicense.Caption := 'Info...';
    edInfo.Text := FTextLicense;
  end else begin
    btLicense.Caption := 'License...';
    edInfo.Text := FTextInfo;
  end;
end;

end.
