unit unRM_FileFuncs;
{
    unRM_FileFuncs - an utility unit with file-related functions.
    Copyright (C) 2003 Roman Mamedov (roman@rm.pp.ru, http://rm.pp.ru/?en)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}

interface

uses Windows, Classes, SysUtils;

const
  PathDelimiter = {$IFDEF win32} '\'{$ELSE} '/'{$ENDIF};

function DirectoryExists(const Name: string): Boolean;
// return the list of files(or files AND directories)
// in the directory Path, which match Mask(e.g. C:\*.txt)
function EnumFiles(const PathMask: string; IncludeDirectories: Boolean):
  TStringList;
function FileLockable(const FileName: string): Boolean;
function ForceDirectories(const Directory: string): Boolean;
function GetCmdLineParameters(var CmdLine: string): string;
//Get file contents as a string
function getfile(const Filename: string): string;
function setfile(const Filename: string; const Contents: string): Boolean;
function GetWindowsDir: string;
function MakeEmptyFile(const FileName: string): Boolean;
//unset read-only attribute and delete the file
function RMDeleteFile(const FileName: string): Boolean;
function RMGetFileSize(const FileName: string): Integer;
//get the DateTime of file's last[w]rite, last[a]ccess or [c]reation.
function RMGetFileTime(const FileName: string; wac: Char): TDateTime;
function IncludeTrailingBackslashX(const Path: string): string;
function ExcludeTrailingBackslash(const Path: string): string;

implementation

function IncludeTrailingBackslashX(const Path: string): string;
begin
  if Trim(Path) = '' then
    Exit;
  if Path[Length(Path)] = PathDelimiter then
    Result := Path
  else
    Result := Path + PathDelimiter;
end;

function ExcludeTrailingBackslash(const Path: string): string;
const
  Delimiter = {$IFDEF unix} '/'{$ELSE} '\'{$ENDIF};
begin
  if Path = '' then
    Exit;
  if Path[Length(Path) - 1] = Delimiter then
    Result := Copy(Path, 0, Length(Path) - 1)
  else
    Result := Path;
end;

function setfile(const Filename: string; const Contents: string): Boolean;
var
  F: TextFile;
begin
  try
    AssignFile(F, Filename);
    Rewrite(F);
    Write(F, Contents);
    CloseFile(F);
    Result := True;
  except
    Result := False;
    try
      CloseFile(F);
    except
    end;
  end;
end;

function getfile(const Filename: string): string;
var
  F: TextFile;
  T: string;
begin
  Result := '';
  try
    AssignFile(F, Filename);
    Reset(F);
    while not EOF(F) do
    begin
      ReadLn(F, T);
      Result := Result + T + #13#10;
    end;
    Result := Trim(Result);    
    CloseFile(F);
  except
    try
      CloseFile(F);
    except
    end;
  end;
end;

function GetWindowsDir: string;
{$IFDEF WIN32}
var
  Buffer: array[0..1023] of Char;
begin
  SetString(Result, Buffer, GetWindowsDirectory(Buffer, SizeOf(Buffer)));
{$ELSE}
begin
  Result[0] := Char(GetWindowsDirectory(@Result[1], 254));
{$ENDIF}
end;

function MakeEmptyFile(const FileName: string): Boolean;
var
  F: file;
begin
  Result := True;
  try
    Assign(F, FileName);
    Rewrite(F);
    CloseFile(F);
  except
    Result := False;
  end;
end;

function FileLockable(const FileName: string): Boolean;
var
  F: Integer;
begin
  if not FileExists(FileName) then
  begin
    Result := True;
    Exit;
  end;
  F := FileOpen(FileName, fmOpenRead or fmShareExclusive);
  Result := not (F = -1);
  FileClose(F);
end;

function EnumFiles(const PathMask: string; IncludeDirectories: Boolean):
  TStringList;
var
  F: TSearchRec;
  Found: Integer;
begin
  Result := TStringList.Create;
  try
    if Trim(PathMask) = '' then
      Exit;
    if IncludeDirectories then
      Found := FindFirst(PathMask, faAnyFile, F)
    else
      Found := FindFirst(PathMask, faAnyFile - faDirectory, F);
    while Found = 0 do
    begin
      if not ((F.Name = '.') or (F.Name = '..')) then
        Result.Add(F.Name);
      Found := FindNext(F);
    end;
    FindClose(F);
  except
    Result.Free;
    Result := nil;
  end;
end;

function RMDeleteFile(const FileName: string): Boolean;
begin
  FileSetAttr(FileName, 0);
  Result := DeleteFile(FileName);
end;

function GetCmdLineParameters(var CmdLine: string): string;
var
  CutPoint: Integer;
begin
  Result := '';
  CutPoint := Pos('.exe ', AnsiLowerCase(CmdLine)) + 4;
  if CutPoint = 0 then
    Exit;
  Result := Copy(CmdLine, CutPoint - 1, $FFFFFFFF);
  CmdLine := Copy(CmdLine, 0, CutPoint);
end;

{$IFDEF win32}
function RMGetFileTime(const FileName:String;WAC:Char):TDateTime;
var
  Fh:Integer;
  Creation, LastAccess, LastWrite, Temp:FILETIME;
  Temp2:TSYSTEMTIME;
begin
  Fh:=FileOpen(FileName,fmOpenRead or fmShareDenyNone);
  GetFileTime(Fh, @Creation, @LastAccess, @LastWrite);
  FileClose(Fh);
  case LowerCase(WAC)[1] of
    'w': Temp := LastWrite;
    'a': Temp := LastAccess;
    else Temp := Creation;
  end;
  try
    FileTimeToLocalFileTime(Temp, Temp);
    FileTimeToSystemTime(Temp, {$IFDEF FPC}@{$ENDIF}Temp2);
    Result := SystemTimeToDateTime(Temp2);
  except
    Result := 0;
  end;
end;
function DirectoryExists(const Name: string): Boolean;
var
  Code: Integer;
begin
  Code := GetFileAttributes(PChar(Name));
  Result := (Code <> -1) and (FILE_ATTRIBUTE_DIRECTORY and Code <> 0);
end;
{$ELSE}
function RMGetFileTime(const FileName:String;WAC:Char):TDateTime;
begin
  // quick&dirty - i only need modification time when running on linux
  // (i.e. for keyplayer)
  Result := FileDateToDateTime(FileAge(FileName));
end;
function DirectoryExists(const Name: string): Boolean;
var
  OCD: string;
begin
  OCD := GetCurrentDir;
  Result := SetCurrentDir(Name);
  SetCurrentDir(OCD);
end;
{$ENDIF}

function RMGetFileSize(const FileName: string): Integer;
var
  F: file of Byte;
begin
  try
    AssignFile(F, FileName);
    FileMode := 0;
    Reset(F);
    Result := FileSize(F);
    CloseFile(F);
  except
    Result := 0;
  end;
end;

function ForceDirectories(const Directory: string): Boolean;
var
  Dir: string;
begin
  Result := True;
  Dir := ExcludeTrailingBackslash(Directory);
  if Length(Dir) = 0 then
    Exit;
  if (Length(Dir) < 3) or DirectoryExists(Dir)
    or (ExtractFilePath(Dir) = Dir) then
    Exit; // avoid 'xyz:\' problem.
  Result := ForceDirectories(ExtractFilePath(Dir)) and CreateDir(Dir);
end;

end.

