unit unRM_Messages;
{
    unRM_Messages - some custom dialog boxes
    Copyright (C) 2003-2004 Roman Mamedov
    <E-Mail: roman@rm.pp.ru, Website: http://rm.pp.ru/?en>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}
interface

uses Windows, Dialogs;

procedure ShowError(const Text: string); overload;
procedure ShowError(const Title, Text: string); overload;
procedure FatalError(const Text: string);
procedure InformErrorCode(const Code,AuthMail: string);
procedure ShowInfo(const Text: string);
function AskUserYN(const Text: string): Boolean;
function WarnUserYN(const Text: string): Boolean;
function ErrorUserYN(const Text: string): Boolean;
function InformUserYN(const Text: string; Error:Boolean): Boolean;
function AskAreYouSure(const Action: string): Boolean;
function WarnAreYouSure(const Action: string): Boolean;

var FATALERROR_FINAL_CLAUSE:String = #13#10#13#10 + 'Application will terminate.';

implementation

procedure FatalErrorChangeFinalClause(const Text:String);
begin
  FATALERROR_FINAL_CLAUSE := #13#10#13#10 + Text;
end;

procedure FatalError(const Text: string);
begin
  ShowError('Fatal Error', Text + FATALERROR_FINAL_CLAUSE);
  Halt;
end;

procedure ShowError(const Text: string);
begin
  MessageDlg(Text, mtError, [mbOK], 0);
end;

procedure ShowError(const Title, Text: string);
begin
  MessageBox(0,PChar(Text),PChar(Title),MB_OK or MB_ICONERROR or MB_TASKMODAL);
end;

procedure InformErrorCode(const Code, AuthMail: string);
var Msg:String;
begin
  Msg:='An error has occured.' + #13#10 + 'The error code is "' + Code + '".';
  if not(AuthMail='') then Msg := Msg + #13#10#13#10 + 'Please contact ' + AUTHMAIL + ' for assistance.';
  ShowError(Msg);
end;

procedure ShowInfo(const Text: string);
begin
  MessageDlg(Text, mtInformation, [mbOK], 0);
end;

function AskAreYouSure(const Action: string): Boolean;
begin
  Result := AskUserYN('Are you sure to ' + Action + '?');
end;

function WarnAreYouSure(const Action: string): Boolean;
begin
  Result := WarnUserYN('Are you sure to ' + Action + '?');
end;

function AskUserYN(const Text: string): Boolean;
begin
  Result := MessageDlg(Text, mtConfirmation, [mbYes, mbNo], 0) = idYes;
end;

function WarnUserYN(const Text: string): Boolean;
begin
  Result := MessageDlg(Text, mtWarning, [mbYes, mbNo], 0) = idYes;
end;

function ErrorUserYN(const Text: string): Boolean;
begin
  Result := MessageDlg(Text, mtError, [mbYes, mbNo], 0) = idYes;
end;

function InformUserYN(const Text: string; Error:Boolean): Boolean;
begin
  if Error then Result:=ErrorUserYN(Text) else Result:=AskUserYN(Text);
end;

end.
